@@ -10,6 +10,7 @@ use overload
 use Plack::Request;
 use Try::Tiny;
 use Params::Validate;
+use lib 't/lib';
 use TestDataHandler;
 
 use Plack::Middleware::Auth::OAuth2::ProtectedResource;
@@ -47,9 +48,10 @@ sub handle_request {
     my ($self, $request) = @_;
     return $request->new_response(200,
         ["Content-Type" => "application/json"],
-        [ sprintf("{user: '%s', scope: '%s'}",
+        [ sprintf("{user: '%s', scope: '%s', is_legacy: '%d'}",
             $request->env->{REMOTE_USER},
-            $request->env->{X_OAUTH_SCOPE})]
+            $request->env->{X_OAUTH_SCOPE},
+            $request->env->{X_OAUTH_IS_LEGACY})]
     );
 }
 
